Module: Rbac::Authorizer
- Extended by:
- ActiveSupport::Concern
- Included in:
- ActionController::API
- Defined in:
- lib/rbac/authorizer.rb
Overview
Authorizer module is responsible for checking if user has access to perform some action.
Authorizer module is responsible for checking if user has access to perform some action.